use crate::components::{CompGetter, CompUi};

#[derive(Debug, Clone)]
pub enum SearchType {
    Name(String),
    Author(String),
    Source(String),
}

#[derive(Debug, Default)]
pub struct SongListNav {
    text: String
}

component_register!(SongListNav);

impl CompUi for SongListNav {
    fn draw(ui: &mut egui::Ui, _: &mut crate::GuiState) -> crate::Result<()> {
        ui.horizontal(|ui| {
            let search_icon = egui::Image::new(crate::data::SEARCH_ICON)
                .fit_to_exact_size(egui::Vec2::new(16.0, 16.0))
                .tint(crate::data::C_ACCENT);
            ui.add(search_icon);
            {
                ui.text_edit_singleline(&mut handle_error_ui!(SongListNav::get()).text);
            }
        });
        Ok(()) 
    }
}

impl SongListNav {
    pub fn parse_search(&self) -> SearchType {
        match &self.text {
            i @ _ if i.starts_with("source:") => 
                SearchType::Source(i.strip_prefix("source:").unwrap_or("").to_string().to_lowercase()),
            i @ _ if i.starts_with("author:") => 
                SearchType::Author(i.strip_prefix("author:").unwrap_or("").to_string().to_lowercase()),
            i @ _ => SearchType::Name(i.to_string().to_lowercase())
        }
    }
}




