use egui::ViewportId;
use xmpd_manifest::store::JsonStore;

use crate::{components::{CompGetter, CompUi}, GuiState};



pub fn draw(ui: &mut egui::Ui, state: &mut GuiState) -> crate::Result<()> {
    // The central panel the region left after adding TopPanel's and SidePanel's
    // ui.heading(format!("Songs ({})", self.manifest.get_song_count()));
    let avail = ui.available_size();
    ui.vertical(|ui| {
        handle_error_ui!(crate::components::top_nav::TopNav::draw(ui, state));
        crate::utils::super_separator(ui, crate::data::C_ACCENT, avail.x, 2.0);
        let avail = ui.available_size();
        let main_height = avail.y * 0.91;

        ui.horizontal(|ui| {
            ui.set_height(main_height);  
            ui.group(|ui| {
                ui.set_height(main_height);
                ui.set_max_width((avail.x * 0.25).clamp(0.0, 200.0));
                handle_error_ui!(crate::components::left_nav::LeftNav::draw(ui, state));
            });
            ui.vertical(|ui| {
                ui.group(|ui| {
                    ui.set_width(avail.x * 0.75);
                    handle_error_ui!(crate::components::song_list::song_list_nav::SongListNav::draw(ui, state));
                });
                ui.group(|ui| {
                    handle_error_ui!(crate::components::song_list::SongList::draw(ui, state));
                });
            });
        });
        egui::TopBottomPanel::new(egui::panel::TopBottomSide::Bottom, "player")
            .frame(
                egui::Frame::none()
                    .fill(crate::data::C_PRIM_BG)
                    .stroke(egui::Stroke::new(
                        1.0,
                        crate::data::C_SEC_BG,
                    )),
            )
            .show(ui.ctx(), |ui| {

            ui.style_mut().visuals.override_text_color = Some(crate::data::C_TEXT);
            handle_error_ui!(crate::components::player::Player::draw(ui, state));
        });
    });
    Ok(())
}


